[Mlir-commits] [mlir] 29120a5 - [MLIR][NFC] Fix clang-tidy errors in Analysis/Presburger/

llvmlistbot at llvm.org llvmlistbot at llvm.org
Sun Jan 2 22:14:04 PST 2022


Author: Groverkss
Date: 2022-01-03T11:42:48+05:30
New Revision: 29120a51307c3f114426649117060d068bc28cfe

URL: https://github.com/llvm/llvm-project/commit/29120a51307c3f114426649117060d068bc28cfe
DIFF: https://github.com/llvm/llvm-project/commit/29120a51307c3f114426649117060d068bc28cfe.diff

LOG: [MLIR][NFC] Fix clang-tidy errors in Analysis/Presburger/

This patch fixes clang-tidy errors related to different parameter names
in header file and source file in Analysis/Presburger/ directory.

Added: 
    

Modified: 
    mlir/include/mlir/Analysis/Presburger/Simplex.h
    mlir/lib/Analysis/Presburger/IntegerPolyhedron.cpp

Removed: 
    


################################################################################
diff  --git a/mlir/lib/Analysis/Presburger/IntegerPolyhedron.cpp b/mlir/lib/Analysis/Presburger/IntegerPolyhedron.cpp
index 627e2bb8728e..03de0e97aaee 100644
--- a/mlir/lib/Analysis/Presburger/IntegerPolyhedron.cpp
+++ b/mlir/lib/Analysis/Presburger/IntegerPolyhedron.cpp
@@ -168,16 +168,16 @@ void IntegerPolyhedron::removeInequality(unsigned pos) {
   inequalities.removeRow(pos);
 }
 
-void IntegerPolyhedron::removeEqualityRange(unsigned begin, unsigned end) {
-  if (begin >= end)
+void IntegerPolyhedron::removeEqualityRange(unsigned start, unsigned end) {
+  if (start >= end)
     return;
-  equalities.removeRows(begin, end - begin);
+  equalities.removeRows(start, end - start);
 }
 
-void IntegerPolyhedron::removeInequalityRange(unsigned begin, unsigned end) {
-  if (begin >= end)
+void IntegerPolyhedron::removeInequalityRange(unsigned start, unsigned end) {
+  if (start >= end)
     return;
-  inequalities.removeRows(begin, end - begin);
+  inequalities.removeRows(start, end - start);
 }
 
 void IntegerPolyhedron::swapId(unsigned posA, unsigned posB) {


        


More information about the Mlir-commits mailing list
diff  --git a/mlir/include/mlir/Analysis/Presburger/Simplex.h b/mlir/include/mlir/Analysis/Presburger/Simplex.h
index 074353aa3a02..87486a481d30 100644
--- a/mlir/include/mlir/Analysis/Presburger/Simplex.h
+++ b/mlir/include/mlir/Analysis/Presburger/Simplex.h
@@ -181,7 +181,7 @@ class SimplexBase {
   void rollback(unsigned snapshot);
 
   /// Add all the constraints from the given IntegerPolyhedron.
-  void intersectIntegerPolyhedron(const IntegerPolyhedron &fac);
+  void intersectIntegerPolyhedron(const IntegerPolyhedron &poly);
 
   /// Returns a rational sample point. This should not be called when Simplex is
   /// empty.
@@ -387,9 +387,9 @@ class Simplex : public SimplexBase {
   /// Check if the specified equality already holds in the polytope.
   bool isRedundantEquality(ArrayRef<int64_t> coeffs);
 
   /// Returns true if this Simplex's polytope is a rational subset of `fac`.
   /// Otherwise, returns false.
-  bool isRationalSubsetOf(const IntegerPolyhedron &fac);
+  bool isRationalSubsetOf(const IntegerPolyhedron &poly);
 
 private:
   friend class GBRSimplex;
@@ -387,9 +387,9 @@ class Simplex : public SimplexBase {
   bool isRedundantEquality(ArrayRef<int64_t> coeffs);
 
-  /// Returns true if this Simplex's polytope is a rational subset of `fac`.
+  /// Returns true if this Simplex's polytope is a rational subset of `poly`.
   /// Otherwise, returns false.
